@@ -3,10 +3,10 @@ testthat::context("write_codemeta")
 testthat::test_that("we can write a codemeta document given a package name", {
   skip_on_cran()
   skip_if_offline()
-
-  write_codemeta("codemetar")
-  testthat::expect_true(file.exists("codemeta.json"))
-  unlink("codemeta.json")
+  path <- tempfile(pattern = "codemetatest", fileext = ".json")
+  write_codemeta("codemetar", path = path, verbose = FALSE)
+  testthat::expect_true(file.exists(path))
+  unlink(path)
 
 })
 
@@ -14,11 +14,12 @@ testthat::test_that("we can write a codemeta document given a package name", {
 testthat::test_that("We can read an existing codemeta.json file", {
   skip_on_cran()
   skip_if_offline()
-
-  write_codemeta("codemetar")
-  testthat::expect_true(file.exists("codemeta.json"))
-  write_codemeta("codemetar")
-  unlink("codemeta.json")
+  path <- tempfile(pattern = "codemetatest", fileext = ".json")
+  write_codemeta("codemetar", path = path, verbose = FALSE)
+  testthat::expect_true(file.exists(path))
+  write_codemeta("codemetar", path = path, verbose = FALSE)
+  testthat::expect_true(file.exists(path))
+  unlink(path)
 
 })
 
@@ -26,11 +27,11 @@ testthat::test_that("We can use either a path or pkg name in writing", {
   skip_on_cran()
   skip_if_offline()
 
-  write_codemeta(path.package("codemetar"))
+  write_codemeta(path.package("codemetar"), verbose = FALSE)
   testthat::expect_true(file.exists("codemeta.json"))
   unlink("codemeta.json")
 
-  write_codemeta("codemetar")
+  write_codemeta("codemetar", verbose = FALSE)
   testthat::expect_true(file.exists("codemeta.json"))
   unlink("codemeta.json")
 
@@ -40,9 +41,9 @@ testthat::test_that("We can deduce relatedLink from installed pkg", {
   skip_on_cran()
   skip_if_offline()
 
-  usethis_cm <- create_codemeta(find.package("usethis"))
-  testthat::expect_true("https://CRAN.R-project.org/package=usethis" %in%
-                          usethis_cm$relatedLink)
+  xml2_cm <- create_codemeta(find.package("xml2"), verbose = FALSE)
+  testthat::expect_true("https://xml2.r-lib.org/" %in%
+                          xml2_cm$relatedLink)
 
 })
 
@@ -51,9 +52,5 @@ testthat::test_that("we can write codemeta given a codemeta object", {
   skip_on_cran()
   skip_if_offline()
   codemeta <- new_codemeta()
-  expect_is(create_codemeta("codemetar", codemeta), "list")
+  expect_is(create_codemeta("codemetar", codemeta, verbose = FALSE), "list")
 })
-
-##(author test below includes such a step already)
-
-
